@@ -306,8 +306,10 @@ fstab_has_device( const char* fname, const char* device, char* mntpt, int *uid )
     FILE* f;
     struct mntent *entry;
     char pathbuf[PATH_MAX];
+    char pathbuf_arg[PATH_MAX];
     static char fstab_device[PATH_MAX];
     char* realdev;
+    char* realdev_arg;
     char* uidopt;
 
     debug("Checking for device '%s' in '%s'\n", device, fname);
@@ -317,23 +319,27 @@ fstab_has_device( const char* fname, const char* device, char* mntpt, int *uid )
         exit( 100 );
     }
 
-    while( ( entry = getmntent( f ) ) != NULL ) {
-        snprintf( fstab_device, sizeof( fstab_device ), "%s", entry->mnt_fsname );
+    if( realpath( device, pathbuf_arg ) )
+      realdev_arg = pathbuf_arg;
+    else {
+      debug("realpath failed on %s : %s\n", device, strerror(errno));
+      realdev_arg = device;
+    }
 
-	/* 
-	   We deactivate the symlink lookup for fstab files: it does
-	   more harm than necessary. After all, the admin should know what
-	   they are doing when they are writing symlinks in /etc/fstab.
-	*/
-        if( 0 && realpath( fstab_device, pathbuf ) )
+    while( ( entry = getmntent( f ) ) != NULL ) {
+        snprintf( fstab_device, sizeof( fstab_device ), "%s", 
+		  entry->mnt_fsname );
+
+        if( realpath( fstab_device, pathbuf ) )
             realdev = pathbuf;
         else
             realdev = fstab_device;
 
-        if( !strcmp( realdev, device ) ) {
+        if( !strcmp( realdev, realdev_arg ) ) {
                 endmntent( f );
                 if( mntpt ) {
-                    snprintf( mntpt, MEDIA_STRING_SIZE-1, "%s", entry->mnt_dir );
+                    snprintf( mntpt, MEDIA_STRING_SIZE-1, "%s", 
+			      entry->mnt_dir );
                 }
                 if( uid ) {
                     uidopt = hasmntopt( entry, "uid" );
@@ -346,6 +352,7 @@ fstab_has_device( const char* fname, const char* device, char* mntpt, int *uid )
                     } else
                         *uid = -1;
                 }
+		debug(" -> found as '%s'", fstab_device);
                 return fstab_device;
         }
     }
@@ -355,6 +362,7 @@ fstab_has_device( const char* fname, const char* device, char* mntpt, int *uid )
         *mntpt = 0; 
 
     endmntent( f );
+    debug(" -> not found");
     return NULL;
 }
 
@@ -501,7 +509,7 @@ device_whitelisted( const char* device )
     }
 
     fclose( fwl );
-   debug( "device_whitlisted(): nothing matched, returning 0\n" );
+    debug( "device_whitlisted(): nothing matched, returning 0\n" );
     return 0;
 }
 
@@ -523,11 +531,15 @@ device_locked( const char* device )
 int
 mntpt_valid( const char* mntpt ) 
 {
-    if( fstab_has_mntpt( "/etc/fstab", mntpt, NULL, 0 ) ) {
-	fprintf( stderr, _("Error: mount point %s is already in /etc/fstab\n"), mntpt );
-	return 0;
-    }
-    return !assert_dir( mntpt, 1 ) && !assert_emptydir( mntpt );
+  char fstab_device[PATH_MAX];
+  if( fstab_has_mntpt( "/etc/fstab", mntpt, fstab_device, 
+		       sizeof(fstab_device) ) ) {
+    fprintf( stderr, _("Error: mount point %s is already in /etc/fstab, "
+		       "associated to device %s\n"), 
+	     mntpt, fstab_device );
+    return 0;
+  }
+  return !assert_dir( mntpt, 1 ) && !assert_emptydir( mntpt );
 }
 
 int
